@@ -6,7 +6,7 @@ use warnings;
 
 use Carp qw< carp croak >;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 use Exporter;
 our @ISA            = qw( Exporter );
@@ -667,14 +667,19 @@ minus infinity. You will get '+inf' when dividing a positive number by 0, and
 
 =over 2
 
+=item Hexadecimal, octal, and binary floating point literals
+
+Perl (and this module) accepts hexadecimal, octal, and binary floating point
+literals, but use them with care with Perl versions before v5.32.0, because some
+versions of Perl silently give the wrong result.
+
 =item Operator vs literal overloading
 
-C<bignum> works by overloading handling of integer and floating point
-literals, converting them to L<Math::BigInt> or L<Math::BigFloat>
-objects.
+C<bignum> works by overloading handling of integer and floating point literals,
+converting them L<Math::BigFloat> objects.
 
-This means that arithmetic involving only string values or string
-literals will be performed using Perl's built-in operators.
+This means that arithmetic involving only string values or string literals are
+performed using Perl's built-in operators.
 
 For example:
 
